jpen.tune: Tuning parameter selection based on minimization of 5 fold mean square error.
Description
Returns optimal values of tuning parameters lambda and gamma which minimizes the K-fold crossvalidation error on
Usage
jpen.tune(Ytr, gama, lambda=NULL)
Arguments
Ytr
Ytr is matrix of observations.
gama
gama is vector of gamma values. gamma is non-negative.
lambda
lambda is vector of lambda values. lambda is non-negative.
Value
Returns the optimal values of lambda and gamma.
Details
Returns the value of optimal tuning parameters. The function uses K-fold cross validation to select the best tuning parameter from among a set of of values of lambda and gamma.
References
A Well Conditioned and Sparse Estimate of Covariance and Inverse Covariance Matrix Using Joint Penalty. Submitted.
http://arxiv.org/pdf/1412.7907v2.pdf